// jshint maxerr:1000
/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* ===============================================================================================================
   ===============================================================================================================
                            POWER TAB TOOL 
   ===============================================================================================================
   =============================================================================================================== */
let Power_Globals = {
    // List of supported devices
    Platforms: {
        'xWRL6432': {
            evms:       {
                'xWRL6432BOOST': {
                    tx_power:   10
                },
                'IWRL6432AOP': {
                    tx_power:   10
                },
                'Custom': {
                    tx_power: 10
                }
            },
            num_tx:     2,
            num_rx:     3,
            silicon_rev: {
                'ES1.0': {
                    powerOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [712.87, 746.89, 824.01],
                            [NaN, 887.77, 962.92],
                        ],
                        interchirpIdle: 328.19,
                        interburstIdle: 115.01,
                        processing: 70.93, 
                        interframeIdle: 11.53,
                        deepSleep: {
                            '3.3V': 1.17,
                            '1.8V': 0.54
                        },
                        interchirpIdleTransitionPower: 987,
                        interburstIdleTransitionPower: 242,
                        interframeIdleTransitionPower: 56,
                        deepSleepTransitionPower: 80
                    },
                    bomOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [935.19, 981.69, 1081.91],
                            [NaN, 1189.13, 1286.82],
                        ],
                        interchirpIdle: 371.29,
                        interburstIdle: 155.76,
                        processing: 100.78,
                        interframeIdle: 19.05,
                        deepSleep: {
                            '3.3V': 1.06,
                            '1.8V': 0.55
                        },
                        interchirpIdleTransitionPower: 1334,
                        interburstIdleTransitionPower: 303,
                        interframeIdleTransitionPower: 81,
                        deepSleepTransitionPower: 107
                    },
                    transitionTimes : {
                        interchirpIdleTime: 10e-6,
                        interburstIdleTime: 90e-6,
                        interframeIdleTime: 1900e-6,
                        deepSleepTime: 2100e-6
                    },
                },
                'ES2.0': {
                    powerOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [681.07, 716.1, 802.79],
                            [NaN, 866.36, 953.5],
                        ],
                        interchirpIdle: 291.92,
                        interburstIdle: 114.85,
                        processing: 77, 
                        interframeIdle: 11.18,
                        deepSleep: {
                            '3.3V': 0.66,
                            '1.8V': 0.48
                        },
                        interchirpIdleTransitionPower: 987,
                        interburstIdleTransitionPower: 242,
                        interframeIdleTransitionPower: 56,
                        deepSleepTransitionPower: 80
                    },
                    bomOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [901.56, 949.59, 1063.67],
                            [NaN, 1173.52, 1288.01],
                        ],
                        interchirpIdle: 332.25,
                        interburstIdle: 151.89,
                        processing: 116,
                        interframeIdle: 18.92,
                        deepSleep: {
                            '3.3V': 0.67,
                            '1.8V': 0.48
                        },
                        interchirpIdleTransitionPower: 1334,
                        interburstIdleTransitionPower: 303,
                        interframeIdleTransitionPower: 81,
                        deepSleepTransitionPower: 107
                    },
                    transitionTimes : {
                        interchirpIdleTime: 10e-6,
                        interburstIdleTime: 90e-6,
                        interframeIdleTime: 1900e-6,
                        deepSleepTime: 2100e-6
                    },
                },
            },
        },
            
        'xWRL1432':      {
            evms:       {
                'xWRL1432BOOST':{
                    tx_power:   10
                },
                'Custom': {
                    tx_power: 10
                }
            },
            num_tx:     2,
            num_rx:     3,
            // 
            silicon_rev:{
                'ES1.0':{
                    powerOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [945, 1013, 1104.23],
                            [NaN, 1267, 1358],
                        ],
                        interchirpIdle: 383,
                        interburstIdle: 119,
                        processing: 159, 
                        interframeIdle: 13.8,
                        deepSleep: {
                            '3.3V': 1.38,
                            '1.8V': 0.64
                        },
                        interchirpIdleTransitionPower: 987,
                        interburstIdleTransitionPower: 242,
                        interframeIdleTransitionPower: 56,
                        deepSleepTransitionPower: 80
                    },
                    bomOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [1271, 1368, 1488.77],
                            [NaN, 1747, 1867],
                        ],
                        interchirpIdle: 420,
                        interburstIdle: 156,
                        processing: 233,
                        interframeIdle: 23.13,
                        deepSleep: {
                            '3.3V': 1.34,
                            '1.8V': 0.78
                        },
                        interchirpIdleTransitionPower: 1334,
                        interburstIdleTransitionPower: 303,
                        interframeIdleTransitionPower: 81,
                        deepSleepTransitionPower: 107
                    },
                    transitionTimes : {
                        interchirpIdleTime: 10e-6,
                        interburstIdleTime: 90e-6,
                        interframeIdleTime: 1900e-6,
                        deepSleepTime: 2100e-6
                    },  
                },
                'ES1.1': {
                    powerOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [891.61, 946.2, 1089.8],
                            [NaN, 1195.1, 1333.1],
                        ],
                        interchirpIdle: 339.95,
                        interburstIdle: 121.17,
                        processing: 159, 
                        interframeIdle: 15.84,
                        deepSleep: {
                            '3.3V': 1.31,
                            '1.8V': 0.65
                        },
                        interchirpIdleTransitionPower: 987,
                        interburstIdleTransitionPower: 242,
                        interframeIdleTransitionPower: 56,
                        deepSleepTransitionPower: 80
                    },
                    bomOptimized: {
                        // [n,m] = (n+1)TX(m+1)RX
                        activeTXRX: [ 
                            [1170.43, 1243.18, 1442.13],
                            [NaN, 1622.56, 1813.71],
                        ],
                        interchirpIdle: 381.89,
                        interburstIdle: 159.91,
                        processing: 233,
                        interframeIdle: 24.46,
                        deepSleep: {
                            '3.3V': 1.36,
                            '1.8V': 0.68
                        },
                        interchirpIdleTransitionPower: 1334,
                        interburstIdleTransitionPower: 303,
                        interframeIdleTransitionPower: 81,
                        deepSleepTransitionPower: 107
                    },
                    transitionTimes : {
                        interchirpIdleTime: 10e-6,
                        interburstIdleTime: 90e-6,
                        interframeIdleTime: 1900e-6,
                        deepSleepTime: 2100e-6
                    },
                },  
            },
            
        },
    },
    
    /**
     * Mapping of front-end input elements and their back-end variables
     */
    Inputs: [
        ['ti_widget_droplist_power_device',           'device',            'dropdown'],
        ['ti_widget_droplist_power_evm',              'evm',               'dropdown'],
        ['ti_widget_droplist_power_mode',             'mode',              'dropdown'],
        ['ti_widget_droplist_power_io_topology',      'io',                'dropdown'],
        ['ti_widget_droplist_power_silicon_rev',      'sili',        'dropdown'],
        ['ti_widget_textbox_power_proc_time',         'proc_time',         'float'],
        ['ti_widget_droplist_power_num_rx',            'num_rx',            'dropdown'],
        ['ti_widget_droplist_power_num_tx',            'num_tx',            'dropdown'],
        ['ti_widget_textbox_power_rampendtime',       'rampendtime',       'float'],
        ['ti_widget_textbox_power_chirpidle',         'chirpidle',         'float'],
        ['ti_widget_textbox_power_numbursts',         'numbursts',         'int'],
        ['ti_widget_textbox_power_frametime',         'frametime',         'float'],
        ['ti_widget_textbox_power_numchirps',         'numchirps',         'int'],
        ['ti_widget_textbox_power_chirps_accum',      'chirps_accum',      'int'],
        ['ti_widget_textbox_power_burst_periodicity', 'burst_periodicity', 'float']
    ],
    /**
     * Default value for each input for each device for each desired configuration default
     */
    Defaults: [
        ['ti_widget_droplist_power_num_rx',           'num_rx',          '3'],
        ['ti_widget_droplist_power_num_tx',           'num_tx',          '2']
    ],
    /**
     * Mapping of front-end output elements and their back-end variables
     */
    Outputs: [
        ['ti_widget_textbox_power_output_active_time',       'active_time',                             'float'],
        ['ti_widget_textbox_power_output_interburst_time',   'interburst_time',                         'float'],
        ['ti_widget_textbox_power_output_proc_time',         'proc_time',                               'float'],
        ['ti_widget_textbox_power_output_interframe_time',   'interframe_time',                         'float'],
        ['ti_widget_textbox_output_active_usage',            'active_usage',                            'float'],
        ['ti_widget_textbox_output_interburst_usage',        'interburst_usage',                        'float'],
        ['ti_widget_textbox_output_proc_usage',              'proc_usage',                              'float'],
        ['ti_widget_textbox_output_interframe_usage',        'interframe_usage',                        'float'],
        ['ti_widget_textbox_output_avg_power',               'avg_power',                               'float']
    ],
};